# Django Aetos Example App

```
./manage.py migrate
./manage.py createsuperuser
./manage.py runserver
```

1. open http://127.0.0.1:8000/admin and add some books
2. view http://127.0.0.1:8000/metrics
